@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::District;
 
-$Map::Tube::London::Line::District::VERSION   = '1.11';
+$Map::Tube::London::Line::District::VERSION   = '1.12';
 $Map::Tube::London::Line::District::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::District - London Tube Map: District Line.
 
 =head1 VERSION
 
-Version 1.11
+Version 1.12
 
 =head1 DESCRIPTION
 
@@ -86,65 +86,143 @@ London Tube Map: District Line.
 
 =over 2
 
-=item * The station "Hammersmith" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
-        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Barons Court" is also part of
-          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Barking" is also part of
-          L<London Overground Line|Map::Tube::London::Line::Overground>.
-
-=item * The station "Earl's Court" is also part of
-          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "South Kensington" is also part of
-          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Victoria" is also part of
-          L<Victoria Line|Map::Tube::London::Line::Victoria>.
-
-=item * The station "Whitechapel" is also part of
-          L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Acton Town" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
 
 =item * The station "Aldgate East" is also part of
-          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
-
-=item * The station "Paddington" is also part of
           L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
-        | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
+
+=item * The station "Barking" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Barons Court" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Bayswater" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Blackfriars" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Bow Road" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Bromley-by-Bow" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Cannon Street" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Ealing Broadway" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
+
+=item * The station "Ealing Common" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Earl's Court" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "East Ham" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
 
 =item * The station "Edgware Road" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>.
-
-=item * The station "High Street Kensington" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>.
-
-=item * The station "Notting Hill Gate" is also part of
-          L<Central Line|Map::Tube::London::Line::Central>.
-
-=item * The station "Mile End" is also part of
-          L<Central Line|Map::Tube::London::Line::Central>.
-
-=item * The station "Gloucester Road" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
 
 =item * The station "Embankment" is also part of
           L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
-        | L<Northern Line|Map::Tube::London::Line::Northern>.
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Northern Line|Map::Tube::London::Line::Northern>
+
+=item * The station "Gloucester Road" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Gunnersbury" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Hammersmith" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "High Street Kensington" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Kensington (Olympia)" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Mansion House" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Mile End" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
 
 =item * The station "Monument" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Notting Hill Gate" is also part of
           L<Central Line|Map::Tube::London::Line::Central>
-        | L<Northern Line|Map::Tube::London::Line::Northern>
-        | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Paddington" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Plaistow" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Richmond" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Sloane Square" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "South Kensington" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "St. James's Park" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Stepney Green" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Temple" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Tower Hill" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Turnham Green" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Upton Park" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+
+=item * The station "Victoria" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Victoria Line|Map::Tube::London::Line::Victoria>
+
+=item * The station "West Brompton" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
 
 =item * The station "West Ham" is also part of
-          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+          L<DLR Line|Map::Tube::London::Line::DLR>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
-        | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
+
+=item * The station "Westminster" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+
+=item * The station "Whitechapel" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Overground Line|Map::Tube::London::Line::Overground>
 
 =back
 
